==> nextcloud-25.0.4.tgz: nextcloud/apps/weather_status/l10n/eu.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Helbide ezezaguna",
    "No result." : "Emaitzarik ez.",
    "Malformed JSON data." : "Gaizki eratutako JSON datuak.",
    "Error" : "Errorea",
    "Weather status" : "Eguraldiaren egoera",
    "Weather status in your dashboard" : "Eguraldiaren egoera zure panelean",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Eguraldiaren egoera panelaren aplikazioan integratuta.\n    Erabiltzailearen kokapena automatikoki zehaztu edo eskuz definitu daiteke. 6 orduko iragarpena bistaratzen da.\n    Egoera hau Egutegia aplikazioa bezalako beste leku batzuetan ere txertatu daiteke.",
    "Detect location" : "Detektatu kokalekua",
    "Set custom address" : "Konfiguratu helbide pertsonalizatua",
    "Favorites" : "Gogokoak",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} oskarbi egongo da geroago",
    "{temperature} {unit} clear sky" : "{temperature} {unit} oskarbi",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} hodeitsu egongo da geroago",
    "{temperature} {unit} cloudy" : "{temperature} {unit} hodeitsu",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} eguraldia hobetuko da geroago",
    "{temperature} {unit} fair weather" : "{temperature} {unit} eguraldi ona",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} hodei-tarteak izango dira geroago",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} hodei-tarteak",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} lainotu egingo da geroago",
    "{temperature} {unit} foggy" : "{temperature} {unit} lainotsu",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} eurite arina gaur beranduago",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} prezipitazio arina",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} prezipitazioa gaur beranduago",
    "{temperature} {unit} rainfall" : "{temperature} {unit} prezipitazioa",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} eurite handia gaur beranduago",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} euri-jasa",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} euri zaparrada gaur beranduago",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} euri zaparradak gaur beranduago",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} zaparrada arinak gaur beranduago",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} zaparrada arinak",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} euri zaparrada handiak gaur beranduago",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} euri zaparrada handiak",
    "More weather for {adr}" : "Eguraldi gehiago {adr}-(e)rako",
    "Loading weather" : "Eguraldia kargatzen",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add as favorite" : "Gehitu gogoko gisa",
    "You are not logged in." : "Ez duzu saioa hasi.",
    "There was an error getting the weather status information." : "Errore bat gertatu da eguraldiaren egoeraren informazioa eskuratzean.",
    "No weather information found" : "Ez da eguraldiaren informaziorik aurkitu",
    "Location not found" : "Ez da kokalekua aurkitu",
    "There was an error setting the location address." : "Errore bat gertatu da kokalekuaren helbidea ezartzean.",
    "There was an error setting the location." : "Errore bat gertatu da kokalekua ezartzean.",
    "There was an error saving the mode." : "Errore bat gertatu da modua gordetzean.",
    "There was an error using personal address." : "Errore bat gertatu da helbide pertsonala erabiltzean.",
    "Set location for weather" : "Ezarri kokalekua eguraldiarentzako"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/weather_status/l10n/eu.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Helbide ezezaguna",
    "No result." : "Emaitzarik ez.",
    "Malformed JSON data." : "Gaizki eratutako JSON datuak.",
    "Error" : "Errorea",
    "Weather status" : "Eguraldiaren egoera",
    "Weather status in your dashboard" : "Eguraldiaren egoera zure panelean",
    "Detect location" : "Detektatu kokalekua",
    "Set custom address" : "Konfiguratu helbide pertsonalizatua",
    "Favorites" : "Gogokoak",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} oskarbi egongo da geroago",
    "{temperature} {unit} clear sky" : "{temperature} {unit} oskarbi",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} hodeitsu egongo da geroago",
    "{temperature} {unit} cloudy" : "{temperature} {unit} hodeitsu",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} eguraldia hobetuko da geroago",
    "{temperature} {unit} fair weather" : "{temperature} {unit} eguraldi ona",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} hodei-tarteak izango dira geroago",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} hodei-tarteak",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} lainotu egingo da geroago",
    "{temperature} {unit} foggy" : "{temperature} {unit} lainotsu",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} eurite arina gaur beranduago",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} prezipitazio arina",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} prezipitazioa gaur beranduago",
    "{temperature} {unit} rainfall" : "{temperature} {unit} prezipitazioa",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} eurite handia gaur beranduago",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} euri-jasa",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} euri zaparrada gaur beranduago",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} euri zaparradak gaur beranduago",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} zaparrada arinak gaur beranduago",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} zaparrada arinak",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} euri zaparrada handiak gaur beranduago",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} euri zaparrada handiak",
    "More weather for {adr}" : "Eguraldi gehiago {adr}-(e)rako",
    "Loading weather" : "Eguraldia kargatzen",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add as favorite" : "Gehitu gogoko gisa",
    "You are not logged in." : "Ez duzu saioa hasi.",
    "There was an error getting the weather status information." : "Errore bat gertatu da eguraldiaren egoeraren informazioa eskuratzean.",
    "No weather information found" : "Ez da eguraldiaren informaziorik aurkitu",
    "Location not found" : "Ez da kokalekua aurkitu",
    "There was an error setting the location address." : "Errore bat gertatu da kokalekuaren helbidea ezartzean.",
    "There was an error setting the location." : "Errore bat gertatu da kokalekua ezartzean.",
    "There was an error saving the mode." : "Errore bat gertatu da modua gordetzean.",
    "There was an error using personal address." : "Errore bat gertatu da helbide pertsonala erabiltzean.",
    "Set location for weather" : "Ezarri kokalekua eguraldiarentzako",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Eguraldiaren egoera panelaren aplikazioan integratuta.\n    Erabiltzailearen kokapena automatikoki zehaztu edo eskuz definitu daiteke. 6 orduko iragarpena bistaratzen da.\n    Egoera hau Egutegia aplikazioa bezalako beste leku batzuetan ere txertatu daiteke."
},
"nplurals=2; plural=(n != 1);");
